index\_calculator.outputwriter
==============================

.. currentmodule:: index_calculator

.. autoclass:: outputwriter


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~outputwriter.__init__
      ~outputwriter.outname
      ~outputwriter.to_netcdf
      ~outputwriter.write_to_netcdf
